==> abi-0.7.10.tar.gz: abi-0.7.10/src/wp/ap/xp/ap_TB_LabelSet_Languages.h <==
/* AbiWord
 * Copyright (C) 1998-2000 AbiSource, Inc.
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
 * 02111-1307, USA.
 */


/*****************************************************************
******************************************************************
** IT IS IMPORTANT THAT THIS FILE ALLOW ITSELF TO BE INCLUDED
** MORE THAN ONE TIME.
******************************************************************
*****************************************************************/

// Include each language file that we want in the build.
// TODO decide if we want to ifdef these...

#include "ap_TB_LabelSet_en-US.h"
#include "ap_TB_LabelSet_ca-ES.h"
#include "ap_TB_LabelSet_es-ES.h"
#include "ap_TB_LabelSet_fi-FI.h"
#include "ap_TB_LabelSet_fr-FR.h"
#include "ap_TB_LabelSet_da-DK.h"
#include "ap_TB_LabelSet_du-NL.h"
#include "ap_TB_LabelSet_de-DE.h"
#include "ap_TB_LabelSet_hu-HU.h"
#include "ap_TB_LabelSet_id-ID.h"
#include "ap_TB_LabelSet_it-IT.h"
#include "ap_TB_LabelSet_no-BOK.h"
#include "ap_TB_LabelSet_sv-SE.h"
#include "ap_TB_LabelSet_pt-PT.h"

==> abi-0.7.12.tar.gz: abi-0.7.12/src/wp/ap/xp/ap_TB_LabelSet_Languages.h <==
/* AbiWord
 * Copyright (C) 1998-2000 AbiSource, Inc.
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
 * 02111-1307, USA.
 */


/*****************************************************************
******************************************************************
** IT IS IMPORTANT THAT THIS FILE ALLOW ITSELF TO BE INCLUDED
** MORE THAN ONE TIME.
******************************************************************
*****************************************************************/

// Include each language file that we want in the build.
// TODO decide if we want to ifdef these...

#include "ap_TB_LabelSet_en-US.h"
#include "ap_TB_LabelSet_ca-ES.h"
#include "ap_TB_LabelSet_cs-CZ.h"
#include "ap_TB_LabelSet_es-ES.h"
#include "ap_TB_LabelSet_fi-FI.h"
#include "ap_TB_LabelSet_fr-FR.h"
#include "ap_TB_LabelSet_da-DK.h"
#include "ap_TB_LabelSet_du-NL.h"
#include "ap_TB_LabelSet_de-DE.h"
#include "ap_TB_LabelSet_hu-HU.h"
#include "ap_TB_LabelSet_id-ID.h"
#include "ap_TB_LabelSet_it-IT.h"
#include "ap_TB_LabelSet_lt-LT.h"
#include "ap_TB_LabelSet_no-BOK.h"
#include "ap_TB_LabelSet_nn-NO.h"
#include "ap_TB_LabelSet_sv-SE.h"
#include "ap_TB_LabelSet_pl-PL.h"
#include "ap_TB_LabelSet_pt-PT.h"
#include "ap_TB_LabelSet_ru-RU.h"
#include "ap_TB_LabelSet_zh-TW.h"
#include "ap_TB_LabelSet_zh-CN.h"
#include "ap_TB_LabelSet_uk-UA.h"
